@@ -985,7 +985,7 @@ class LongestCommonSubsequence(StringAlignment):
             list_of_list_separator (str): Separator to use when the inputs are lists of strings.
         """
         # Initialize the StringAlignment class.
-        super().__init__()
+        super().__init__(match_weight=1, mismatch_weight=0, gap_weight=0)
 
         # Set the list of list separator.
         self.list_of_list_separator = list_of_list_separator
